@@ -24,7 +24,7 @@ from stevedore import extension
 
 from ceilometer import declarative
 from ceilometer.i18n import _
-from ceilometer import notification
+from ceilometer.pipeline import sample as endpoint
 from ceilometer import sample as sample_util
 
 OPTS = [
@@ -183,12 +183,12 @@ class MeterDefinition(object):
             yield sample
 
 
-class ProcessMeterNotifications(notification.NotificationProcessBase):
+class ProcessMeterNotifications(endpoint.SampleEndpoint):
 
     event_types = []
 
-    def __init__(self, manager):
-        super(ProcessMeterNotifications, self).__init__(manager)
+    def __init__(self, conf, publisher):
+        super(ProcessMeterNotifications, self).__init__(conf, publisher)
         self.definitions = self._load_definitions()
 
     def _load_definitions(self):
@@ -196,18 +196,18 @@ class ProcessMeterNotifications(notification.NotificationProcessBase):
             namespace='ceilometer.event.trait_plugin')
         definitions = {}
         mfs = []
-        for dir in self.manager.conf.meter.meter_definitions_dirs:
+        for dir in self.conf.meter.meter_definitions_dirs:
             for filepath in sorted(glob.glob(os.path.join(dir, "*.yaml"))):
                 if filepath is not None:
                     mfs.append(filepath)
-        if self.manager.conf.meter.meter_definitions_cfg_file is not None:
+        if self.conf.meter.meter_definitions_cfg_file is not None:
             mfs.append(
                 pkg_resources.resource_filename(
-                    self.manager.conf.meter.meter_definitions_cfg_file)
+                    self.conf.meter.meter_definitions_cfg_file)
             )
         for mf in mfs:
             meters_cfg = declarative.load_definitions(
-                self.manager.conf, {}, mf)
+                self.conf, {}, mf)
 
             for meter_cfg in reversed(meters_cfg['metric']):
                 if meter_cfg.get('name') in definitions:
@@ -216,8 +216,7 @@ class ProcessMeterNotifications(notification.NotificationProcessBase):
                                 % meter_cfg)
                     continue
                 try:
-                    md = MeterDefinition(meter_cfg, self.manager.conf,
-                                         plugin_manager)
+                    md = MeterDefinition(meter_cfg, self.conf, plugin_manager)
                 except declarative.DefinitionException as e:
                     errmsg = "Error loading meter definition: %s"
                     LOG.error(errmsg, six.text_type(e))
@@ -225,8 +224,8 @@ class ProcessMeterNotifications(notification.NotificationProcessBase):
                     definitions[meter_cfg['name']] = md
         return definitions.values()
 
-    def process_notification(self, notification_body):
+    def build_sample(self, notification):
         for d in self.definitions:
-            if d.match_type(notification_body['event_type']):
-                for s in d.to_samples(notification_body):
+            if d.match_type(notification['event_type']):
+                for s in d.to_samples(notification):
                     yield sample_util.Sample.from_notification(**s)
