@@ -19,7 +19,6 @@ import logging.handlers
 from oslo_log import log
 from six.moves.urllib import parse as urlparse
 
-from ceilometer.i18n import _LE
 from ceilometer import publisher
 
 LOG = log.getLogger(__name__)
@@ -39,10 +38,8 @@ class FilePublisher(publisher.ConfigPublisherBase):
 
         -
             name: meter_file
-            interval: 600
-            counters:
+            meters:
                 - "*"
-            transformers:
             publishers:
                 - file:///var/test?max_bytes=10000000&backup_count=5
 
@@ -58,7 +55,7 @@ class FilePublisher(publisher.ConfigPublisherBase):
         self.publisher_logger = None
         path = parsed_url.path
         if not path:
-            LOG.error(_LE('The path for the file publisher is required'))
+            LOG.error('The path for the file publisher is required')
             return
 
         rfh = None
@@ -72,8 +69,8 @@ class FilePublisher(publisher.ConfigPublisherBase):
                     max_bytes = int(params.get('max_bytes')[0])
                     backup_count = int(params.get('backup_count')[0])
                 except ValueError:
-                    LOG.error(_LE('max_bytes and backup_count should be '
-                                  'numbers.'))
+                    LOG.error('max_bytes and backup_count should be '
+                              'numbers.')
                     return
         # create rotating file handler
         rfh = logging.handlers.RotatingFileHandler(
