@@ -73,9 +73,8 @@ class TestNotifications(base.BaseTestCase):
         self.setup_messaging(self.CONF)
 
     def test_process_request_notification(self):
-        sample = list(middleware.HTTPRequest(mock.Mock()).process_notification(
-            HTTP_REQUEST
-        ))[0]
+        sample = list(middleware.HTTPRequest(
+            mock.Mock(), mock.Mock()).build_sample(HTTP_REQUEST))[0]
         self.assertEqual(HTTP_REQUEST['payload']['request']['HTTP_X_USER_ID'],
                          sample.user_id)
         self.assertEqual(HTTP_REQUEST['payload']['request']
@@ -86,7 +85,7 @@ class TestNotifications(base.BaseTestCase):
 
     def test_process_response_notification(self):
         sample = list(middleware.HTTPResponse(
-            mock.Mock()).process_notification(HTTP_RESPONSE))[0]
+            mock.Mock(), mock.Mock()).build_sample(HTTP_RESPONSE))[0]
         self.assertEqual(HTTP_RESPONSE['payload']['request']['HTTP_X_USER_ID'],
                          sample.user_id)
         self.assertEqual(HTTP_RESPONSE['payload']['request']
@@ -94,7 +93,3 @@ class TestNotifications(base.BaseTestCase):
         self.assertEqual(HTTP_RESPONSE['payload']['request']
                          ['HTTP_X_SERVICE_NAME'], sample.resource_id)
         self.assertEqual(1, sample.volume)
-
-    def test_targets(self):
-        targets = middleware.HTTPRequest(mock.Mock()).get_targets(self.CONF)
-        self.assertEqual(13, len(targets))
