@@ -14,17 +14,17 @@
 
 import mock
 
-from oslo_config import fixture as fixture_config
 from oslotest import base
 
 from ceilometer import neutron_client
+from ceilometer import service
 
 
 class TestNeutronClient(base.BaseTestCase):
 
     def setUp(self):
         super(TestNeutronClient, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
         self.nc = neutron_client.Client(self.CONF)
         self.nc.lb_version = 'v1'
 
