@@ -11,9 +11,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-
-from ceilometer.agent import manager
+from ceilometer.polling import manager
 from ceilometer import service
 import ceilometer.tests.base as base
 from ceilometer.volume import cinder
@@ -67,6 +65,7 @@ SNAPSHOT_LIST = [
           u'os-extended-snapshot-attributes:project_id':
               u'6824974c08974d4db864bbaa6bc08303',
           u'size': 1,
+          u'user_id': u'be255bd31eb944578000fc762fde6dcf',
           u'updated_at': u'2016-10-19T07:56:55.000000',
           u'id': u'b1ea6783-f952-491e-a4ed-23a6a562e1cf',
           u'volume_id': u'6f27bc42-c834-49ea-ae75-8d1073b37806',
@@ -104,7 +103,6 @@ BACKUP_LIST = [
 
 
 class TestVolumeSizePollster(base.BaseTestCase):
-    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
         super(TestVolumeSizePollster, self).setUp()
         conf = service.prepare_service([], [])
@@ -124,7 +122,6 @@ class TestVolumeSizePollster(base.BaseTestCase):
 
 
 class TestVolumeSnapshotSizePollster(base.BaseTestCase):
-    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
         super(TestVolumeSnapshotSizePollster, self).setUp()
         conf = service.prepare_service([], [])
@@ -139,6 +136,8 @@ class TestVolumeSnapshotSizePollster(base.BaseTestCase):
         self.assertEqual('volume.snapshot.size',
                          volume_snapshot_size_samples[0].name)
         self.assertEqual(1, volume_snapshot_size_samples[0].volume)
+        self.assertEqual('be255bd31eb944578000fc762fde6dcf',
+                         volume_snapshot_size_samples[0].user_id)
         self.assertEqual('6824974c08974d4db864bbaa6bc08303',
                          volume_snapshot_size_samples[0].project_id)
         self.assertEqual('b1ea6783-f952-491e-a4ed-23a6a562e1cf',
@@ -146,7 +145,6 @@ class TestVolumeSnapshotSizePollster(base.BaseTestCase):
 
 
 class TestVolumeBackupSizePollster(base.BaseTestCase):
-    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
         super(TestVolumeBackupSizePollster, self).setUp()
         conf = service.prepare_service([], [])
